import java.math.BigInteger

const val MAX_LEN = 28
const val MOD = 998_244_353

fun modPow(base: Long, exp: Long): Int {
    @Suppress("NAME_SHADOWING")
    var exp = exp

    var res = 1L
    var cur = base
    while (exp > 0) {
        if (exp % 2 == 1L) {
            res *= cur
            res %= MOD
        }
        cur *= cur
        cur %= MOD
        exp /= 2
    }

    return res.toInt()
}

fun modVal(value: String): Int {
    var res = 0L
    for (c in value) {
        res = 10L * res % MOD
        res += (c - '0')
    }

    return (res % MOD).toInt()
}

data class Result(val len: Int, val value: String, val offset: Int): Comparable<Result> {
    fun value(): Int {
        var ans = 1L
        for (l in 1 until len) {
            ans += 9L * modPow(10, l - 1L) % MOD * l % MOD
            ans %= MOD
        }

        val numVals = (modVal(value) + MOD - modPow(10, len - 1L)) % MOD
        ans += 1L * numVals * len % MOD
        ans += offset

        return (ans % MOD).toInt()
    }

    override operator fun compareTo(other: Result): Int = when {
        this.len != other.len -> this.len compareTo other.len
        this.value != other.value -> this.value compareTo other.value
        else -> this.offset compareTo other.offset
    }
}

// Create everything from lo to hi, inclusive
fun create(lo: BigInteger, hi: BigInteger): String {
    var sb = StringBuilder()
    var x = lo
    while (x != hi) {
        sb.append(x.toString())
        x++
    }

    return sb.toString()
}

fun isMatch(s: String, t: String, offset: Int): Boolean =
    s.withIndex().all { (i, x) -> x == '?' || t[i + offset] == x }

fun solve(prefix: String, powers: Array<String>): Int {
    val s = readln()

    // brute force the prefix
    for (i in 0 until (prefix.length - s.length)) {
        if (isMatch(s, prefix, i)) {
            return (i + 1) % MOD
        }
    }

    var ans = run {
        var t = s.toCharArray()
        if (t[0] == '?') t[0] = '1'
        for (i in 1 until s.length) {
            if (t[i] == '?') t[i] = '0'
        }

        // This is a nasty edge case that would have tripped me up without the samples
        if (t[0] == '0') {
            val big = CharArray(s.length + 1) { if (it == 0) { '1' } else { t[it - 1] } }
            Result(s.length + 1, String(big), 1)
        } else {
            Result(s.length, String(t), 0)
        }
    }

    // Note this has to be inclusive, because of the patch above
    for (len in 3..(s.length + 1)) {
        if (ans.len < len) {
            break
        }

        for (offset in 0 until len) {
            val numNums = (offset + s.length + len - 1) / len
            val q = CharArray(numNums * len) { when {
                it < offset -> '?'
                it - offset >= s.length -> '?'
                else -> s[it - offset]
            } }.joinToString("")

            fun getDigit(numIdx: Int, digitIdx: Int): Char =
                q[numIdx * len + digitIdx]

            fun sameDigit(numIdx: Int, digitIdx: Int, digit: Int): Boolean {
                val qDigit = getDigit(numIdx, digitIdx)
                return qDigit == '?' || qDigit == ('0' + digit)
            }

            // Is this column always digit?
            fun canFix(digitIdx: Int, digit: Int): Boolean {
                if (digitIdx == 0 && digit == 0) {
                    return false
                }

                return (0 until numNums).all { sameDigit(it, digitIdx, digit) }
            }

            // Is it possible for this column to begin as digit and then become digit + 1?
            fun canFixFuzzy(digitIdx: Int, digit: Int): Boolean {
                if (digitIdx == 0 && digit == 0) {
                    return false
                }

                var curDigit = digit
                // TODO: there has to be a simpler way...
                for (idx in 0 until numNums) {
                    if (sameDigit(idx, digitIdx, curDigit)) {
                        continue
                    }
                    val nextDigit = (digit + 1) % 10
                    if (idx > 0 && curDigit == digit && sameDigit(idx, digitIdx, nextDigit)) {
                        curDigit = nextDigit
                    } else {
                        return false
                    }
                }

                return curDigit != digit || getDigit(numNums - 1, digitIdx) == '?'
            }

            var fixDigit = IntArray(len) { i -> (0 until 10).filter { d -> canFix(i, d) }.minOrNull() ?: 10 }
            val isFuzzyNine = BooleanArray(len) { canFixFuzzy(it, 9) }

            for (tail in 0 until 100) {
                val isValid = (0 until numNums).all {
                    val v = (tail + it) % 100
                    val ones = v % 10
                    val tens = v / 10

                    sameDigit(it, len - 1, ones) and sameDigit(it, len - 2, tens)
                }

                if (!isValid) {
                    continue
                }

                var number = CharArray(len) { '?' }

                for (fixedPrefixLen in 0 until len) {
                    val canPrefix = (0 until fixedPrefixLen).all { fixDigit[it] < 10 }
                    val canNine = ((fixedPrefixLen + 1) until (len-2)).all { isFuzzyNine[it] }

                    if (!canPrefix || !canNine) {
                        continue
                    }

                    for (i in 0 until fixedPrefixLen) {
                        number[i] = ('0' + fixDigit[i])
                    }

                    for (fuzzDigit in 0 until 10) {
                        if (!canFix(fixedPrefixLen, fuzzDigit) and !canFixFuzzy(fixedPrefixLen, fuzzDigit)) {
                            continue
                        }
                        number[fixedPrefixLen] = ('0' + fuzzDigit)

                        for (i in (fixedPrefixLen + 1) until len) {
                            number[i] = '9'
                        }

                        number[len - 2] = '0' + (tail / 10)
                        number[len - 1] = '0' + (tail % 10)
                        val sn = String(number)
                        val base = BigInteger(sn)
                        val bigStr = create(base, base + BigInteger.valueOf(numNums.toLong()))

                        if (isMatch(s, bigStr, offset)) {
                            val res = Result(len, sn, offset)
                            if (res < ans) {
                                ans = res
                            }
                        }
                    }
                }
            }
        }

        // Now handle the cross-length cases
        val p10 = BigInteger.TEN.pow(len)
        var v = p10 - BigInteger.TEN
        outer@ for (inc in 0 until 10) {
            for (offset in 0 until len) {
                if (isMatch(s, powers[len], inc * len + offset)) {
                    val res = Result(len, v.toString(), offset)
                    if (res < ans) {
                        ans = res
                        break@outer
                    }
                }
            }
            v++
        }
    }

    // System.err.println(ans)
    return ans.value()
}

fun main() {
    val prefix = create(BigInteger.ONE, BigInteger.valueOf(100L + MAX_LEN))
    val powers = Array(MAX_LEN + 1) { "" }
    for (len in 3..MAX_LEN) {
        // TODO: shrink these if needed for speed. Bound changes based on the max answer
        val x = BigInteger.TEN.pow(len)
        powers[len] = create(x - BigInteger.TEN, x + BigInteger.TEN)
    }

    val t = readln().toInt()
    repeat (t) {
        val ans = solve(prefix, powers)
        println(ans)
    }
}
